"""create initial tables (Project, files, wikidata)

Revision ID: f397bfd28419
Revises: 
Create Date: 2020-07-12 18:20:01.400590

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'f397bfd28419'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('project',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('name', sa.String(length=64), nullable=True),
    sa.Column('creation_date', sa.DateTime(), nullable=False),
    sa.Column('modification_date', sa.DateTime(), nullable=False),
    sa.Column('sparql_endpoint', sa.String(length=64), nullable=True),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_project'))
    )
    with op.batch_alter_table('project', schema=None) as batch_op:
        batch_op.create_index(batch_op.f('ix_project_name'), ['name'], unique=False)

    op.create_table('wikidata_item',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('wd_id', sa.String(length=64), nullable=True),
    sa.Column('label', sa.String(length=300), nullable=True),
    sa.Column('description', sa.String(length=1000), nullable=True),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_wikidata_item'))
    )
    with op.batch_alter_table('wikidata_item', schema=None) as batch_op:
        batch_op.create_index(batch_op.f('ix_wikidata_item_wd_id'), ['wd_id'], unique=False)

    op.create_table('wikidata_property',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('wd_id', sa.String(length=64), nullable=True),
    sa.Column('property_type', sa.String(length=64), nullable=True),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_wikidata_property'))
    )
    with op.batch_alter_table('wikidata_property', schema=None) as batch_op:
        batch_op.create_index(batch_op.f('ix_wikidata_property_wd_id'), ['wd_id'], unique=False)

    op.create_table('saved_file',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('file_path', sa.String(length=300), nullable=True),
    sa.Column('extension', sa.String(length=20), nullable=True),
    sa.Column('name', sa.String(length=100), nullable=True),
    sa.Column('project_id', sa.Integer(), nullable=True),
    sa.Column('type', sa.String(length=50), nullable=True),
    sa.ForeignKeyConstraint(['project_id'], ['project.id'], name=op.f('fk_saved_file_project_id_project')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_saved_file'))
    )
    op.create_table('datafile',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('current_sheet_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['id'], ['saved_file.id'], name=op.f('fk_datafile_id_saved_file')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_datafile'))
    )
    op.create_table('propertyfile',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['saved_file.id'], name=op.f('fk_propertyfile_id_saved_file')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_propertyfile'))
    )
    op.create_table('wikifierfile',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['saved_file.id'], name=op.f('fk_wikifierfile_id_saved_file')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_wikifierfile'))
    )
    op.create_table('yamlfile',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['id'], ['saved_file.id'], name=op.f('fk_yamlfile_id_saved_file')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_yamlfile'))
    )
    op.create_table('data_sheet',
    sa.Column('id', sa.Integer(), nullable=False),
    sa.Column('name', sa.String(length=64), nullable=True),
    sa.Column('data_file_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['data_file_id'], ['datafile.id'], name=op.f('fk_data_sheet_data_file_id_datafile')),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_data_sheet'))
    )
    op.create_table('datafile_wiki',
    sa.Column('wikifier_id', sa.Integer(), nullable=True),
    sa.Column('data_file_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['data_file_id'], ['datafile.id'], name=op.f('fk_datafile_wiki_data_file_id_datafile')),
    sa.ForeignKeyConstraint(['wikifier_id'], ['wikifierfile.id'], name=op.f('fk_datafile_wiki_wikifier_id_wikifierfile'))
    )
    op.create_table('yaml_sheet',
    sa.Column('sheet_id', sa.Integer(), nullable=True),
    sa.Column('yaml_id', sa.Integer(), nullable=True),
    sa.ForeignKeyConstraint(['sheet_id'], ['data_sheet.id'], name=op.f('fk_yaml_sheet_sheet_id_data_sheet')),
    sa.ForeignKeyConstraint(['yaml_id'], ['yamlfile.id'], name=op.f('fk_yaml_sheet_yaml_id_yamlfile'))
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('yaml_sheet')
    op.drop_table('datafile_wiki')
    op.drop_table('data_sheet')
    op.drop_table('yamlfile')
    op.drop_table('wikifierfile')
    op.drop_table('propertyfile')
    op.drop_table('datafile')
    op.drop_table('saved_file')
    with op.batch_alter_table('wikidata_property', schema=None) as batch_op:
        batch_op.drop_index(batch_op.f('ix_wikidata_property_wd_id'))

    op.drop_table('wikidata_property')
    with op.batch_alter_table('wikidata_item', schema=None) as batch_op:
        batch_op.drop_index(batch_op.f('ix_wikidata_item_wd_id'))

    op.drop_table('wikidata_item')
    with op.batch_alter_table('project', schema=None) as batch_op:
        batch_op.drop_index(batch_op.f('ix_project_name'))

    op.drop_table('project')
    # ### end Alembic commands ###
